# Janos version 1.2.1
# JanosEquation.py
# by Antoine Rauzy
# Copyrights (c) 2018-2022 AltaRica Association
#
# This file is part of Janos, a pedagogical stochastic simulator.
# Janos is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Janos is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with Janos.  If not, see <http://www.gnu.org/licenses/>.

# Table of Contents
# -----------------
# 1) Imported modules
# 2) Equations

# 1) Imported modules
# -------------------

from S2MLCore import *

from JanosType import *

# 2) Equations
# ------------

class JanosEquation(S2MLElement):
  def __init__(self, type, container):
    S2MLElement.__init__(self, type, container)
    self._members = []
    self._index = 0

  @staticmethod
  def NewAssignment(leftMember, rightMember, container):
    equation = JanosEquation(JanosType.ASSIGNMENT, container)
    equation.AppendMember(leftMember)
    equation.AppendMember(rightMember)
    return equation

  @staticmethod
  def NewDoubleAssignment(leftMember, rightMember, container):
    equation = JanosEquation(JanosType.DOUBLE_ASSIGNMENT, container)
    equation.AppendMember(leftMember)
    equation.AppendMember(rightMember)
    return equation

  def GetNumberOfMembers(self):
    return len(self._members)
  def GetMembers(self):
    return self._members
  def GetMember(self, i):
    if i<0 or i>=self.GetNumberOfMembers():
      return None
    return self._members[i]
  def AppendMember(self, member):
    self._members.append(member)
  def AppendMembers(self, members):
    self._members.extend(member)
  def RemoveMember(self, member):
    self._members.remove(member)
  def RemoveAllMembers(self):
    self._members.clear()
  def GetLeftMember(self):
    return self.GetMember(0)
  def GetRightMember(self):
    return self.GetMember(1)

  def GetIndex(self):
    return self._index
  def SetIndex(self, index):
    self._index = index
