# S2MLCore version 1.1.1
# S2MLCommand.py
# by Antoine Rauzy
# Copyrights (c) 2018-2022 AltaRica Association
#
# This file is part of S2MLCore.
# S2MLCore is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# S2MLCore is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with S2MLCore.  If not, see <http://www.gnu.org/licenses/>.

# Table of Contents
# -----------------
# 1) Imported modules
# 2) Creator
# 3) Access methods
# 4) Children
# 5) Arguments
# 6) Options

# 1) Imported modules
# -------------------

import sys

# 2) Creator
# ----------

class S2MLCommand:
  SCRIPT = 0
  BUILTIN = 1

  def __init__(self, type):
    self._type = type
    self._fileName = None
    self._lineNumber = None
    self._commands = []
    self._name = None
    self._arguments = []
    self._options = dict()

  @staticmethod
  def NewScript():
    command = S2MLCommand(S2MLCommand.SCRIPT)
    return command

  @staticmethod
  def NewBuiltIn(name):
    command = S2MLCommand(S2MLCommand.BUILTIN)
    command._name = name
    return command

# 3) Access methods
# -----------------

  def GetType(self):
    return self._type

  def GetFileName(self):
    return self._fileName

  def SetFileName(self, fileName):
    self._fileName = fileName

  def GetLineNumber(self):
    return self._lineNumber

  def SetLineNumber(self, lineNumber):
    self._lineNumber = lineNumber

  def GetName(self):
    return self._name

# 4) Commands
# -----------

  def GetCommands(self):
    return self._commands

  def AppendCommand(self, command):
    self._commands.append(command)

# 5) Arguments
# ------------

  def GetArguments(self):
    return self._arguments

  def AppendArgument(self, argument):
    self._arguments.append(argument)

  def GetNumberOfArguments(self):
    return len(self._arguments)

  def GetArgument(self, index):
    if index<0 or index>=self.GetNumberOfArguments():
      return None
    return self._arguments[index]

  def GetArgumentAsBoolean(self, index):
    argument = self.GetArgument(index)
    if argument==None:
      return None
    return argument.GetValueOfBoolean()

  def GetArgumentAsInteger(self, index):
    argument = self.GetArgument(index)
    if argument==None:
      return None
    return argument.GetValueOfInteger()

  def GetArgumentAsReal(self, index):
    argument = self.GetArgument(index)
    if argument==None:
      return None
    return argument.GetValueOfReal()

  def GetArgumentAsIdentifier(self, index):
    argument = self.GetArgument(index)
    if argument==None:
      return None
    return argument.GetValueOfIdentifier()

  def GetArgumentAsString(self, index):
    argument = self.GetArgument(index)
    if argument==None:
      return None
    return argument.GetValueOfString()

# 6) Options
# ----------

  def GetOptions(self):
    return self._options

  def GetOption(self, name):
    return self._options.get(name, None)

  def SetOption(self, name, value):
     self._options[name] = value
